@@ -23,12 +23,12 @@ cwd = os.getcwd()
 try:
     os.chdir(os.path.dirname(__file__))
     if os.name == 'nt':
-        # assume that the directory of libtiff.dll is in PATH.
-        lib = ctypes.util.find_library('libtiff.dll')
-        if lib is None:
-            # Fallback to the old "libtiff3" name
-            lib = ctypes.util.find_library('libtiff3')
-        if lib is None:
+        # assume that the directory of the libtiff DLL is in PATH.
+        for lib in ('tiff', 'libtiff', 'libtiff3'):
+            lib = ctypes.util.find_library(lib)
+            if lib is not None:
+                break
+        else:
             # try default installation path:
             lib = r'C:\Program Files\GnuWin32\bin\libtiff3.dll'
             if os.path.isfile(lib):
@@ -68,6 +68,7 @@ libtiff_version_str = libtiff.TIFFGetVersion()
 i = libtiff_version_str.lower().split().index(b'version')
 assert i != -1, repr(libtiff_version_str.decode())
 libtiff_version = libtiff_version_str.split()[i + 1].decode()
+libtiff_version_tuple = tuple(int(i) for i in libtiff_version.split('.'))
 
 tiff_h_name = 'tiff_h_%s' % (libtiff_version.replace('.', '_'))
 try:
@@ -75,6 +76,17 @@ try:
 except ImportError:
     tiff_h = None
 
+
+def _generate_lines_without_continuations(file_obj):
+    """Parse lines from tiff.h but concatenate lines using a backslahs for continuation."""
+    line_iter = iter(file_obj)
+    for header_line in line_iter:
+        while header_line.endswith("\\\n"):
+            # line continuation - replace '<extra space>\<NL><indentation>' with a single space
+            header_line = header_line[:-2].rstrip() + " " + next(line_iter).lstrip()
+        yield header_line
+
+
 if tiff_h is None:
     # WARNING: there is not guarantee that the tiff.h found below will
     # correspond to libtiff version. Although, for clean distros the
@@ -82,6 +94,8 @@ if tiff_h is None:
 
     include_tiff_h = os.path.join(os.path.split(lib)[0], '..', 'include',
                                   'tiff.h')
+    if not os.path.isfile(include_tiff_h):
+        include_tiff_h = os.environ.get('TIFF_HEADER_PATH', include_tiff_h)
     if not os.path.isfile(include_tiff_h):
         include_tiff_h = os.path.join(os.path.split(lib)[0], 'include',
                                       'tiff.h')
@@ -107,7 +121,7 @@ if tiff_h is None:
     f = open(include_tiff_h, 'r')
     lst = []
     d = {}
-    for line in f.readlines():
+    for line in _generate_lines_without_continuations(f):
         if not line.startswith('#define'):
             continue
         words = line[7:].lstrip().split()
@@ -169,11 +183,16 @@ for name, value in list(d.items()):
 
 
 # types defined by tiff.h
-class c_ttag_t(ctypes.c_uint):
+class c_ttag_t(ctypes.c_uint32):
     pass
 
 
-class c_tdir_t(ctypes.c_uint16):
+if libtiff_version_tuple[:2] >= (4, 5):
+    c_tdir_t_base = ctypes.c_uint32
+else:
+    c_tdir_t_base = ctypes.c_uint16
+
+class c_tdir_t(c_tdir_t_base):
     pass
 
 
@@ -189,7 +208,7 @@ class c_ttile_t(ctypes.c_uint32):
     pass
 
 
-class c_tsize_t(ctypes.c_int32):
+class c_tsize_t(ctypes.c_ssize_t):
     pass
 
 
@@ -1219,16 +1238,16 @@ class TIFF(ctypes.c_void_p):
     def WriteScanline(self, buf, row, sample=0):
         return libtiff.TIFFWriteScanline(self, buf, row, sample)
     writescanline = WriteScanline
-    
+
     @debug
-    def ReadScanline(self, buf, row, sample=0): 
+    def ReadScanline(self, buf, row, sample=0):
         return libtiff.TIFFReadScanline(self, buf, row, sample)
     readscanline = ReadScanline
-    
-    def ScanlineSize(self): 
+
+    def ScanlineSize(self):
         return libtiff.TIFFScanlineSize(self).value
     scanlinesize = ScanlineSize
-    
+
     # @debug
     def ReadRawStrip(self, strip, buf, size):
         return libtiff.TIFFReadRawStrip(self, strip, buf, size).value
