@@ -237,7 +237,7 @@ class TIFFfile(TiffBase):
             bytes = type2bytes.get(typ)
             if dtype is None or bytes is None:
                 warnings.warn('incomplete info for type=%r [%r]: dtype=%s, bytes=%s\n' % (
-                    typ, ntyp, dtype, bytes))
+                    typ, ntyp, dtype, bytes), stacklevel=2)
                 return
         return self.data[offset:offset + bytes * count].view(dtype=dtype)
 
